@@ -73,6 +73,7 @@ run_edit_dialog (gchar *string, gchar *title)
 
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
 	dbox = GTK_DIALOG (dialog)->vbox;
@@ -429,6 +430,7 @@ show_preferences_dialog (BonoboUIComponent *uic,
 			 gtk_widget_get_screen (curr_data->applet));
   gtk_window_set_default_size (GTK_WINDOW (curr_data->propwindow), 350, 350);
   gtk_container_set_border_width (GTK_CONTAINER (curr_data->propwindow), 5);
+  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (curr_data->propwindow)->vbox), 2);
   gtk_dialog_set_default_response (GTK_DIALOG (curr_data->propwindow), GTK_RESPONSE_CLOSE);
   gtk_dialog_set_has_separator (GTK_DIALOG (curr_data->propwindow), FALSE);
 
