@@ -99,12 +99,12 @@ about_cb (BonoboUIComponent *uic,
 /* run the full-scale system process monitor */
 
 static void
-start_procman_cb (BonoboUIComponent *uic,
-		  MultiloadApplet   *ma,
-		  const char        *name)
+start_procman (MultiloadApplet *ma)
 {
 	GError *error = NULL;
 
+	g_return_if_fail (ma != NULL);
+	
 	egg_screen_execute_command_line_async (
 			gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
 			"gnome-system-monitor", &error);
@@ -114,8 +114,8 @@ start_procman_cb (BonoboUIComponent *uic,
 		dialog = gtk_message_dialog_new (NULL,
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
 						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_CLOSE,
-						 _("There was an error executing '%s' : %s"),
+						 GTK_BUTTONS_OK,
+						 _("There was an error executing '%s': %s"),
 						 "gnome-system-monitor",
 						 error->message);
 
@@ -133,23 +133,20 @@ start_procman_cb (BonoboUIComponent *uic,
 	}
 }
               
+static void
+start_procman_cb (BonoboUIComponent *uic,
+		  MultiloadApplet   *ma,
+		  const char        *name)
+{
+	start_procman (ma);
+}
+
 void
 multiload_change_size_cb(PanelApplet *applet, gint size, gpointer data)
 {
-	gint i;
 	MultiloadApplet *ma = (MultiloadApplet *)data;
-
-	for (i = 0; i < 5; i++) {
-		ma->graphs[i]->pixel_size = size;
-  	  	if (ma->graphs[i]->orient) 
-  	  		gtk_widget_set_size_request (ma->graphs[i]->main_widget, 
-					             ma->graphs[i]->pixel_size, 
-						     ma->graphs[i]->size);
-		else
-			gtk_widget_set_size_request (ma->graphs[i]->main_widget, 
-							     ma->graphs[i]->size, 
-							     ma->graphs[i]->pixel_size);
-	}
+	
+	multiload_applet_refresh(ma);
 	
 	return;
 }
@@ -169,7 +166,7 @@ multiload_destroy_cb(GtkWidget *widget, gpointer data)
 	gint i;
 	MultiloadApplet *ma = data;
 	
-	for (i = 0; i < 5; i++)
+	for (i = 0; i < NGRAPHS; i++)
 	{
 		if (ma->graphs[i]->visible)
 		{
@@ -194,7 +191,7 @@ multiload_enter_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
 
 	ma = (MultiloadApplet *)data;
 	
-	for (i = 0; i < 5; i++)
+	for (i = 0; i < NGRAPHS; i++)
 		if (ma->graphs[i]->visible)
 		{
 			ma->graphs[i]->tooltip_update = TRUE;
@@ -212,13 +209,52 @@ multiload_leave_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
 
 	ma = (MultiloadApplet *)data;
 
-	for (i = 0; i < 5; i++)
+	for (i = 0; i < NGRAPHS; i++)
 		if (ma->graphs[i]->visible)
 			ma->graphs[i]->tooltip_update = FALSE;
 		
 	return TRUE;
 }
 
+static gboolean
+multiload_button_press_event_cb (GtkWidget *widget, GdkEventButton *event, MultiloadApplet *ma)
+{
+	g_return_val_if_fail (event != NULL, FALSE);
+	g_return_val_if_fail (ma != NULL, FALSE);
+
+	if (event->button == 1 && event->type == GDK_2BUTTON_PRESS) {
+		start_procman (ma);
+		return TRUE;
+	}
+	return FALSE;
+}
+
+static gboolean
+multiload_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MultiloadApplet *ma)
+{
+	g_return_val_if_fail (event != NULL, FALSE);
+	g_return_val_if_fail (ma != NULL, FALSE);
+
+	switch (event->keyval) {
+	/* this list of keyvals taken from mixer applet, which seemed to have
+		a good list of keys to use */
+	case GDK_KP_Enter:
+	case GDK_ISO_Enter:
+	case GDK_3270_Enter:
+	case GDK_Return:
+	case GDK_space:
+	case GDK_KP_Space:
+		/* activate */
+		start_procman (ma);
+		return TRUE;
+
+	default:
+		break;
+	}
+
+	return FALSE;
+}
+
 /* update the tooltip to the graph's current "used" percentage */
 void
 multiload_applet_tooltip_update(LoadGraph *g)
@@ -240,6 +276,8 @@ multiload_applet_tooltip_update(LoadGraph *g)
 		name = g_strdup(_("Network"));
 	else if (!strncmp(g->name, "swapload", strlen("swapload")))
 		name = g_strdup(_("Swap Space"));
+	else if (!strncmp(g->name, "loadavg", strlen("loadavg")))
+		name = g_strdup(_("Load Average"));
 	else
 		name = g_strdup(_("Resource"));
 	
@@ -248,10 +286,9 @@ multiload_applet_tooltip_update(LoadGraph *g)
 	
 	for (i = 0; i < (g->n - 1); i++)
 		total_used += g->data[0][i];
-	/* netload has a fifth data structute */
-	if (!strncmp(g->name, "netload", strlen("netload")))
-		total_used += g->data[0][g->n - 1];	
+	
 	percent = 100 * (gdouble)total_used / (gdouble)g->draw_height;
+	percent = CLAMP (percent, 0, 100);
 
 	tooltip_text = g_strdup_printf(_("%s:\n%d%% in use"), name, percent);
 	gtk_tooltips_set_tip(g->tooltips, g->disp, tooltip_text, tooltip_text);
@@ -270,8 +307,11 @@ multiload_applet_refresh(MultiloadApplet *ma)
 	PanelAppletOrient orientation;
 	
 	/* stop and free the old graphs */
-	for (i = 0; i < 5; i++)
+	for (i = 0; i < NGRAPHS; i++)
 	{
+		if (!ma->graphs[i])
+			continue;
+			
 		if (ma->graphs[i]->visible)
 		{
 			load_graph_stop(ma->graphs[i]);
@@ -282,7 +322,8 @@ multiload_applet_refresh(MultiloadApplet *ma)
 		g_free(ma->graphs[i]);
 	}
 
-	gtk_widget_destroy(ma->box);
+	if (ma->box)
+		gtk_widget_destroy(ma->box);
 	
 	orientation = panel_applet_get_orient(ma->applet);
 	
@@ -295,7 +336,7 @@ multiload_applet_refresh(MultiloadApplet *ma)
 	
 	gtk_container_add(GTK_CONTAINER(ma->applet), ma->box);
 			
-	/* create the 5 graphs, passing in their user-configurable properties with gconf. */
+	/* create the NGRAPHS graphs, passing in their user-configurable properties with gconf. */
 	
 	ma->graphs[0] = cpuload_applet_new(ma->applet, NULL);
 	ma->graphs[1] = memload_applet_new(ma->applet, NULL);
@@ -305,10 +346,10 @@ multiload_applet_refresh(MultiloadApplet *ma)
 	
 	/* only start and display the graphs the user has turned on */
 
-	for (i = 0; i < 5; i++) {
+	for (i = 0; i < NGRAPHS; i++) {
 	    gtk_box_pack_start(GTK_BOX(ma->box), 
 			       ma->graphs[i]->main_widget, 
-			       FALSE, FALSE, 1);
+			       TRUE, TRUE, 1);
 	    if (ma->graphs[i]->visible) {
 	    	gtk_widget_show_all (ma->graphs[i]->main_widget);
 		load_graph_start(ma->graphs[i]);
@@ -331,11 +372,7 @@ static const BonoboUIVerb multiload_menu_verbs [] = {
 gboolean
 multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 {
-	gint i;
-	GtkWidget *box;
-	PanelAppletOrient orientation;
 	MultiloadApplet *ma;
-	gboolean visible = FALSE;
 	
 	ma = g_new0(MultiloadApplet, 1);
 	
@@ -344,43 +381,7 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-monitor.png");
 	
 	panel_applet_add_preferences (applet, "/schemas/apps/multiload/prefs", NULL);
-	
-	orientation = panel_applet_get_orient(applet);
-	
-	if ( (orientation == PANEL_APPLET_ORIENT_UP) || (orientation == PANEL_APPLET_ORIENT_DOWN) )
-		box = gtk_hbox_new(FALSE, 0);
-	else
-		box = gtk_vbox_new(FALSE, 0);
-	
-	gtk_container_add(GTK_CONTAINER(applet), box);
-	
-	/* create the 5 graphs, passing in their user-configurable properties with gconf. */
-	ma->graphs[0] = cpuload_applet_new(applet, NULL);
-	ma->graphs[1] = memload_applet_new(applet, NULL);
-	ma->graphs[2] = netload_applet_new(applet, NULL);
-	ma->graphs[3] = swapload_applet_new(applet, NULL);
-	ma->graphs[4] = loadavg_applet_new(applet, NULL);
-
-	/* only start and display the graphs the user has turned on */
-	for (i = 0; i < 5; i++) {
-	    gtk_box_pack_start(GTK_BOX(box), 
-			       ma->graphs[i]->main_widget, 
-			       FALSE, FALSE, 1);
-	    if (ma->graphs[i]->visible) {
-	    	gtk_widget_show_all (ma->graphs[i]->main_widget);
-		load_graph_start(ma->graphs[i]);
-		visible = TRUE;
-	    }
-	}
-	
-	if (!visible) {
-		/* No graphs shown - need to show at least one so show cpu*/
-		ma->graphs[0]->visible = TRUE;
-		gtk_widget_show_all (ma->graphs[0]->main_widget);
-		load_graph_start(ma->graphs[0]);
-		panel_applet_gconf_set_bool(ma->applet, "view_cpuload", 
-			                    TRUE, NULL);
-	}
+	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 
 	panel_applet_setup_menu_from_file (applet,
 					   NULL,
@@ -388,8 +389,6 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 					   NULL,
 					   multiload_menu_verbs,
 					  ma);	
-
-	ma->box = box;
 	
 	g_signal_connect(G_OBJECT(applet), "change_size",
 				G_CALLBACK(multiload_change_size_cb), ma);
@@ -399,10 +398,13 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 				G_CALLBACK(multiload_destroy_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "enter_notify_event",
 				G_CALLBACK(multiload_enter_cb), ma);
-	multiload_change_size_cb (ma->applet,
-				  panel_applet_get_size (ma->applet),
-				  ma);	
-	gtk_widget_show (box);			
+	g_signal_connect(G_OBJECT(applet), "button_press_event",
+				G_CALLBACK(multiload_button_press_event_cb), ma);
+	g_signal_connect(G_OBJECT(applet), "key_press_event",
+				G_CALLBACK(multiload_key_press_event_cb), ma);
+	
+	multiload_applet_refresh (ma);
+		
 	gtk_widget_show(GTK_WIDGET(applet));
 			
 	return TRUE;
